@@ -345,8 +345,9 @@ static int dbd_db_connect( SV *dbh,
                    "connect '%s', '%s', '%s'", dbname, uid, pwd );
 
   /*
-   * The SQL_ATTR_CONNECT_NODE attribute must be set prior
-   * to establishing the connection:
+   * The SQL_ATTR_CONNECT_NODE and SQL_ATTR_LOGIN_TIMEOUT
+   * attribute must be set prior to establishing the
+   * connection:
    */
   if( SvROK( attr ) && SvTYPE( SvRV( attr ) ) == SVt_PVHV )
   {
@@ -364,6 +365,18 @@ static int dbd_db_connect( SV *dbh,
       if( SQL_SUCCESS != ret )
         goto exit;
     }
+
+    pval = hv_fetch( attrh, "db2_login_timeout", 17, 0 );
+    if( NULL != pval )
+    {
+      ret = SQLSetConnectAttr( imp_dbh->hdbc,
+                               SQL_ATTR_LOGIN_TIMEOUT,
+                               (SQLPOINTER)SvIV( *pval ),
+                               0 );
+      ret = check_error( dbh, ret, "Set login timeout failed" );
+      if( SQL_SUCCESS != ret )
+        goto exit;
+    }
   }
 
   ret = SQLConnect(imp_dbh->hdbc,dbname,SQL_NTS,uid,SQL_NTS,pwd,SQL_NTS);
@@ -679,7 +692,6 @@ static SQLINTEGER getConnectAttr( char *key,
    *   SQL_ATTR_CONNECTTYPE         2-phase commit not supported
    *   SQL_ATTR_CONN_CONTEXT        Doesn't make sense for DBD::DB2
    *   SQL_ATTR_ENLIST_IN_DTC       Doesn't make sense for DBD::DB2
-   *   SQL_ATTR_LOGIN_TIMEOUT       Not supported by DB2 CLI
    *   SQL_ATTR_MAXCONN             For NetBIOS
    *   SQL_ATTR_OPTIMIZE_SQLCOLUMNS
    *   SQL_ATTR_SYNC_POINT          2-phase commit not supported
@@ -740,6 +752,8 @@ static SQLINTEGER getConnectAttr( char *key,
     case 17:
       if(      strEQ( key, "db2_info_applname" ) )
         return SQL_ATTR_INFO_APPLNAME;
+      else if( strEQ( key, "db2_login_timeout" ) )
+        return SQL_ATTR_LOGIN_TIMEOUT;
       else if( strEQ( key, "db2_txn_isolation" ) )
         return SQL_ATTR_TXN_ISOLATION;
       return -1;
@@ -831,6 +845,7 @@ int dbd_db_STORE_attrib( SV *dbh,
 #ifndef AS400
     case SQL_ATTR_DB2ESTIMATE:
     case SQL_ATTR_DB2EXPLAIN:
+    case SQL_ATTR_LOGIN_TIMEOUT:
     case SQL_ATTR_QUIET_MODE:
     case SQL_ATTR_TXN_ISOLATION:
 #endif
@@ -859,8 +874,6 @@ int dbd_db_STORE_attrib( SV *dbh,
     default:
       return FALSE;
   }
-
-
   ret = SQLSetConnectAttr( imp_dbh->hdbc,
                            Attribute,
                            ValuePtr,
@@ -962,6 +975,7 @@ SV *dbd_db_FETCH_attrib( SV *dbh,
       case SQL_ATTR_CONNECT_NODE:
       case SQL_ATTR_DB2ESTIMATE:
       case SQL_ATTR_DB2EXPLAIN:
+      case SQL_ATTR_LOGIN_TIMEOUT:
       case SQL_ATTR_QUIET_MODE:
       case SQL_ATTR_TXN_ISOLATION:
 #endif
@@ -2915,6 +2929,7 @@ int dbd_st_STORE_attrib( SV *sth,
     /* Integers */
     case SQL_ATTR_CONCURRENCY:
 #ifndef AS400
+    case SQL_ATTR_LOGIN_TIMEOUT:
     case SQL_ATTR_MAX_LENGTH:
     case SQL_ATTR_MAX_ROWS:
 #endif
@@ -3173,6 +3188,7 @@ SV *dbd_st_FETCH_attrib( SV *sth,
         /* Integers */
         case SQL_ATTR_CONCURRENCY:
 #ifndef AS400
+        case SQL_ATTR_LOGIN_TIMEOUT:
         case SQL_ATTR_MAX_LENGTH:
         case SQL_ATTR_MAX_ROWS:
 #endif
